#install.packages('hrbrthemes')
library(tidyverse)      ## language extension
library(broom)          ## computing lots of linear models and other stuff in a compact way
library(hrbrthemes)     ## nice-looking plot themes
library(readxl)

setwd("~/Documents/Lemaitre_Lab/Frontiers vs MDPI/BLOGPOST")

# data in [change the absolute path]
df <- read_excel("~/Documents/Lemaitre_Lab/Frontiers vs MDPI/BLOGPOST/IF_SJR_Data.xlsx")
head(df)

Pub<-as.factor(df$Pub)
Journal<-df$Journal
IF_SJR<-df$IF_SJR

#Violin plots
library(ggplot2)
#install.packages("Hmisc")
library(Hmisc)
# Basic violin plot
quartz(h=6.5,w=6) ## The equivalent for a PC is windows()
# Set trim argument to FALSE
p <- ggplot(df, aes(x=reorder(Pub,IF_SJR, mean), y=IF_SJR), xlab="Publisher", ylab="IF/SJR") + 
  geom_violin(trim=TRUE)
# violin plot add quartiles
p2<-p + geom_boxplot(width=0.1, cex=0.5,)
#Or alternately trying to add sumary stats directly
#p2<-p+ stat_summary(fun.data = mean_sdl, fun.args = list(mult = 1), fatten=10, geom="pointrange", shape=3, color="black")
p3<-p2 + geom_jitter(position=position_jitter(0.15), aes(colour = Pub), cex=0.5)#shape=Exp,
#Adjust labels
p4<-p3 + labs(x = "", y = "IF/SJR")
#No legend
p5<-p4 + theme(legend.position = "none")
p6<-p5 + theme(axis.title.y = element_text(size=20))
p7<-p6 + theme(axis.text.x = element_text(size=10, angle=30, vjust = .8, hjust = 1))
p8<-p7 + geom_hline(size=0.2, color = "blue", linetype = "dashed", yintercept=4)
p8

###STATISTICS
# Compute the analysis of variance
res.aov <- aov(IF_SJR ~ Pub, data = df) #Trt p = 2.5e-10, Exp p = .0004
# Summary of the analysis
summary(res.aov)
#Multiple comparisons (all comparisons)
TukeyHSD(res.aov)

#  Tukey multiple comparisons of means
#    95% family-wise confidence level
#
#Fit: aov(formula = IF_SJR ~ Pub, data = df)
#
#$Pub
#                              diff        lwr        upr     p adj
#BMC-Bentham            -2.71198396 -3.8076822 -1.6162857 0.0000000
#Comp of Biol-Bentham   -3.41563599 -5.1509248 -1.6803472 0.0000004
#Frontiers-Bentham      -2.19909742 -3.3089918 -1.0892030 0.0000004
#MDPI-Bentham           -0.95498865 -2.0371313  0.1271540 0.1227352
#NFP-Bentham            -3.78423823 -5.2399208 -2.3285557 0.0000000
#PLoS-Bentham           -3.68826281 -5.2495636 -2.1269621 0.0000000
#Comp of Biol-BMC       -0.70365203 -2.1883395  0.7810355 0.7940461
#Frontiers-BMC           0.51288655 -0.1389842  1.1647573 0.2281410
#MDPI-BMC                1.75699531  1.1535861  2.3604045 0.0000000
#NFP-BMC                -1.07225427 -2.2177155  0.0732070 0.0829647
#PLoS-BMC               -0.97627885 -2.2532792  0.3007215 0.2595691
#Frontiers-Comp of Biol  1.21653858 -0.2786564  2.7117335 0.1937784
#MDPI-Comp of Biol       2.46064734  0.9859355  3.9353592 0.0000310
#NFP-Comp of Biol       -0.36860224 -2.1357338  1.3985293 0.9960330
#PLoS-Comp of Biol      -0.27262681 -2.1277285  1.5824749 0.9994493
#MDPI-Frontiers          1.24410877  0.6152895  1.8729280 0.0000004
#NFP-Frontiers          -1.58514081 -2.7441889 -0.4260927 0.0013109
#PLoS-Frontiers         -1.48916539 -2.7783671 -0.1999637 0.0124039
#NFP-MDPI               -2.82924958 -3.9617511 -1.6967481 0.0000000
#PLoS-MDPI              -2.73327416 -3.9986627 -1.4678857 0.0000000
#PLoS-NFP                0.09597542 -1.5006419  1.6925928 0.9999971

#groups
#a = NFP, PLoS, CoB, BMC
#b = CoB, BMC, Frontiers
#c = MDPI, Bentham

########################
#What happens if you unite PLoS and CoB
########################
#  Tukey multiple comparisons of means
#    95% family-wise confidence level
#
#Fit: aov(formula = IF_SJR ~ Pub, data = df)
#
#$Pub
#                         diff        lwr         upr     p adj
#BMC-Bentham        -2.7119840 -3.7680104 -1.65595753 0.0000000
#Frontiers-Bentham  -2.1990974 -3.2688061 -1.12938878 0.0000002
#MDPI-Bentham       -0.9549887 -1.9979503  0.08797304 0.0936083
#NFP-Bentham        -3.7842382 -5.1872151 -2.38126138 0.0000000
#PLoS/CoB-Bentham   -3.5746683 -4.8820900 -2.26724664 0.0000000
#Frontiers-BMC       0.5128865 -0.1153820  1.14115512 0.1792984
#MDPI-BMC            1.7569953  1.1754337  2.33855693 0.0000000
#NFP-BMC            -1.0722543 -2.1762420  0.03173345 0.0623758
#PLoS/CoB-BMC       -0.8626843 -1.8423763  0.11700757 0.1191008
#MDPI-Frontiers      1.2441088  0.6380571  1.85016045 0.0000002
#NFP-Frontiers      -1.5851408 -2.7022235 -0.46805818 0.0009166
#PLoS/CoB-Frontiers -1.3755709 -2.3699958 -0.38114594 0.0013568
#NFP-MDPI           -2.8292496 -3.9207468 -1.73775238 0.0000000
#PLoS/CoB-MDPI      -2.6196797 -3.5852745 -1.65408476 0.0000000
#PLoS/CoB-NFP        0.2095699 -1.1368878  1.55602768 0.9976886

#groups
#a = NFP, PLoS/CoB, BMC
#b = BMC, Frontiers
#c = MDPI, Bentham


quartz(h=6,w=9) ## The equivalent for a PC is windows()
par(mfrow=c(2,2),mar=par()$mar+c(0,0,0,7), pty="s", xpd=TRUE)
#Multiple comparisons (pairwise t.test)
# Box plot
boxplot(IF_SJR ~ Pub, data = df,
        xlab = "Pub", ylab = "IF_SJR",
        frame = FALSE)
plot(res.aov, 1) #plot residuals, 15 and 20 detected as outliers
plot(res.aov, 2)

# Extract the residuals
aov_residuals <- residuals(object = res.aov )
# Run Shapiro-Wilk test
shapiro.test(x = aov_residuals )#Shapiro-Wilk normality test: data:  aov_residuals: W = 0.98085, p-value = 0.1504
text(3,-1,
"Shapiro-Wilk normality test

data:  aov_residuals
W = 0.89249, p-value = 2.537e-10",cex=.75) #prior to exp removed = W = 0.98356, p-value = 0.07837

######REMOVED BENTHAM#######
# data in [change the absolute path]
df2 <- read_excel("~/Documents/Lemaitre_Lab/Frontiers vs MDPI/BLOGPOST/IF_SJR_Data_noBentham.xlsx")
head(df2)

Pub2<-as.factor(df2$Pub)
levels(Pub2)
Journal2<-df2$Journal
IF_SJR2<-df2$IF_SJR

###STATISTICS
# Compute the analysis of variance
res.aov <- aov(IF_SJR2 ~ Pub2, data = df2) #Trt p = 2.5e-10, Exp p = .0004
# Summary of the analysis
summary(res.aov)
#Multiple comparisons (all comparisons)
TukeyHSD(res.aov)

#  Tukey multiple comparisons of means
#    95% family-wise confidence level
#
#Fit: aov(formula = IF_SJR2 ~ Pub2, data = df2)
#
#$Pub2
#                              diff         lwr         upr     p adj
#Comp of Biol-BMC       -0.70365203 -1.99388968  0.58658562 0.6180757
#Frontiers-BMC           0.51288655 -0.05360856  1.07938165 0.1004912
#MDPI-BMC                1.75699531  1.23261478  2.28137585 0.0000000
#NFP-BMC                -1.07225427 -2.06769423 -0.07681431 0.0266507
#PLoS-BMC               -0.97627885 -2.08603018  0.13347249 0.1196465
#Frontiers-Comp of Biol  1.21653858 -0.08283038  2.51590753 0.0807596
#MDPI-Comp of Biol       2.46064734  1.17907880  3.74221588 0.0000017
#NFP-Comp of Biol       -0.36860224 -1.90429221  1.16708773 0.9826554
#PLoS-Comp of Biol      -0.27262681 -1.88476545  1.33951183 0.9965571
#MDPI-Frontiers          1.24410877  0.69764610  1.79057143 0.0000000
#NFP-Frontiers          -1.58514081 -2.59238815 -0.57789348 0.0001552
#PLoS-Frontiers         -1.48916539 -2.60952003 -0.36881075 0.0024350
#NFP-MDPI               -2.82924958 -3.81342713 -1.84507204 0.0000000
#PLoS-MDPI              -2.73327416 -3.83293445 -1.63361387 0.0000000
#PLoS-NFP                0.09597542 -1.29153260  1.48348345 0.9999559

#groups
#a = NFP, PLoS, CoB
#b = PLoS, CoB, BMC
#c = CoB, BMC, Frontiers
#d = MDPI

########################
#What happens if you unite PLoS and CoB
########################
#  Tukey multiple comparisons of means
#    95% family-wise confidence level
#
#Fit: aov(formula = IF_SJR2 ~ Pub2, data = df2)
#
#$Pub2
#                         diff        lwr         upr     p adj
#Frontiers-BMC       0.5128865 -0.0277548  1.05352789 0.0719925
#MDPI-BMC            1.7569953  1.2565465  2.25744412 0.0000000
#NFP-BMC            -1.0722543 -2.0222642 -0.12224430 0.0183073
#PLoS/CoB-BMC       -0.8626843 -1.7057346 -0.01963412 0.0420839
#MDPI-Frontiers      1.2441088  0.7225856  1.76563191 0.0000000
#NFP-Frontiers      -1.5851408 -2.5464193 -0.62386233 0.0000998
#PLoS/CoB-Frontiers -1.3755709 -2.2312993 -0.51984251 0.0001605
#NFP-MDPI           -2.8292496 -3.7685111 -1.88998803 0.0000000
#PLoS/CoB-MDPI      -2.6196797 -3.4505990 -1.78876029 0.0000000
#PLoS/CoB-NFP        0.2095699 -0.9490918  1.36823163 0.9873969

#groups
#a = NFP, PLoS/CoB
#b = BMC, Frontiers
#c = MDPI

quartz(h=6,w=9) ## The equivalent for a PC is windows()
par(mfrow=c(2,2),mar=par()$mar+c(0,0,0,7), pty="s", xpd=TRUE)
#Multiple comparisons (pairwise t.test)
# Box plot
boxplot(IF_SJR2 ~ Pub2, data = df2,
        xlab = "Pub", ylab = "IF_SJR",
        frame = FALSE, cex.axis = .4)
plot(res.aov, 1) #plot residuals, 15 and 20 detected as outliers
plot(res.aov, 2) 
text(11,-2,
"  Tukey multiple comparisons of means
    95% family-wise confidence level

Fit: aov(formula = IF_SJR2 ~ Pub2, data = df2)

                         diff        lwr         upr     p adj
Frontiers-BMC       0.5128865 -0.0277548  1.05352789 0.0719925
MDPI-BMC            1.7569953  1.2565465  2.25744412 0.0000000
NFP-BMC            -1.0722543 -2.0222642 -0.12224430 0.0183073
PLoS/CoB-BMC       -0.8626843 -1.7057346 -0.01963412 0.0420839
MDPI-Frontiers      1.2441088  0.7225856  1.76563191 0.0000000
NFP-Frontiers      -1.5851408 -2.5464193 -0.62386233 0.0000998
PLoS/CoB-Frontiers -1.3755709 -2.2312993 -0.51984251 0.0001605
NFP-MDPI           -2.8292496 -3.7685111 -1.88998803 0.0000000
PLoS/CoB-MDPI      -2.6196797 -3.4505990 -1.78876029 0.0000000
PLoS/CoB-NFP        0.2095699 -0.9490918  1.36823163 0.9873969", cex=.4, pos = 2)

# Extract the residuals
aov_residuals <- residuals(object = res.aov )
# Run Shapiro-Wilk test
shapiro.test(x = aov_residuals )#Shapiro-Wilk normality test: data:  aov_residuals: W = 0.98085, p-value = 0.1504
text(11,5,
"Shapiro-Wilk normality test

data:  aov_residuals
W = 0.92673, p-value = 9.277e-08",cex=.75, pos = 2) #prior to exp removed = W = 0.98356, p-value = 0.07837

#Violin plots
library(ggplot2)
#install.packages("Hmisc")
library(Hmisc)
# Basic violin plot
quartz(h=6.5,w=6) ## The equivalent for a PC is windows()
# Set trim argument to FALSE
p <- ggplot(df2, aes(x=reorder(Pub,IF_SJR, mean), y=IF_SJR), xlab="Publisher", ylab="IF/SJR") + 
  geom_violin(trim=TRUE)
# violin plot add quartiles
p2<-p + geom_boxplot(width=0.1, cex=0.5,)
#Or alternately trying to add sumary stats directly
#p2<-p+ stat_summary(fun.data = mean_sdl, fun.args = list(mult = 1), fatten=10, geom="pointrange", shape=3, color="black")
p3<-p2 + geom_jitter(position=position_jitter(0.15), aes(colour = Pub), cex=0.5)#shape=Exp,
#Adjust labels
p4<-p3 + labs(x = "", y = "IF/SJR")
#No legend
p5<-p4 + theme(legend.position = "none")
p6<-p5 + theme(axis.title.y = element_text(size=20))
p7<-p6 + theme(axis.text.x = element_text(size=10, angle=30, vjust = .8, hjust = 1))
p8<-p7 + geom_hline(size=0.2, color = "blue", linetype = "dashed", yintercept=4)
p8

#summary stats
summary(df$IF_SJR[Pub=='NFP'])
summary(df$IF_SJR[Pub=='PLoS/CoB'])
summary(df$IF_SJR[Pub=='BMC'])
summary(df$IF_SJR[Pub=='Frontiers'])
summary(df$IF_SJR[Pub=='MDPI'])
summary(df$IF_SJR[Pub=='Bentham'])

#> #summary stats
#> summary(df$IF_SJR[Pub=='NFP'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  1.385   1.720   1.942   1.938   2.236   2.447 
#> summary(df$IF_SJR[Pub=='Comp of Biol'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  1.830   2.217   2.423   2.306   2.474   2.588 
#> summary(df$IF_SJR[Pub=='PLoS'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  1.424   1.678   1.945   2.034   2.118   3.273 
#> summary(df$IF_SJR[Pub=='BMC'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  1.784   2.535   2.775   3.010   3.199   7.522 
#> summary(df$IF_SJR[Pub=='Frontiers'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  1.715   2.905   3.269   3.523   3.910   6.158 
#> summary(df$IF_SJR[Pub=='MDPI'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  2.761   3.986   4.638   4.767   5.548   7.047 
#> summary(df$IF_SJR[Pub=='Bentham'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  3.390   4.759   5.222   5.722   6.146  11.578 
#> summary(df$IF_SJR[Pub=='PLoS/CoB'])
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
#  1.424   1.793   2.085   2.147   2.436   3.273 